#!/bin/bash
#
#   USAGE:  tarArtDaq.sh <product-dir> <qualifier> <opt|debug|prof> [source]
#  qualifiers: e2 e2:nompi nu:e2:nompi

if [ $# -lt 1 ]
then
   echo "USAGE:  `basename ${0}` <product-dir> <qualifier> <opt|debug|prof> [source]"
   exit 1
fi

PRODUCTS=${1}
artqual=${2}
extraqual=${3}
extras=${4}

pkgver=v0_03_01
dotversion=0.03.01
cetbuildtools_version=v2_05_06

if [ ! -d ${PRODUCTS} ]
then
   echo "USAGE:  `basename ${0}` <product-dir> <qualifier> [debug|opt|prof] [source|cet]"
   exit 1
fi

if [ "${extras}" = "source" ]
then
  set -x
  cd ${PRODUCTS}
  tar cjf artdaq-${dotversion}-source.tar.bz2 \
   cetbuildtools/${cetbuildtools_version}.version cetbuildtools/${cetbuildtools_version} \
   artdaq/${pkgver}/*.sh \
   artdaq/${pkgver}/cet
  set +x
  exit 0
fi

# require qualifier
if [ -z ${artqual} ]
then
   echo "ERROR: qualifier not specified"
   echo "USAGE:  `basename ${0}` <product-dir> <qualifier> [debug|opt|prof] [source|cet]"
   exit 1
fi
if [ "${artqual}" = "e2" ]
then
   fcldir=artdaq/${pkgver}/fcl
fi

if [ "${extraqual}" = "opt" ]
then
   echo "OK - building tarball for ${extraqual}"
elif [ "${extraqual}" = "debug" ]
then
   echo "OK - building tarball for ${extraqual}"
elif [ "${extraqual}" = "prof" ]
then
   echo "OK - building tarball for ${extraqual}"
else
   echo "ERROR: please define the extra qualifier"
   echo "USAGE:  `basename ${0}` <product-dir> <qualifier> <opt|debug|prof> [source]"
   exit 1
fi

source ${PRODUCTS}/setup

OS1=`uname`

if [ ${OS1} = "Darwin" ]
then
    flvr=`ups flavor -2`
    plat=`uname -m`
    OSnum=`uname -r | cut -f1 -d"."`
    macos=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1,2`
    macos1=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 1`
    macos2=`system_profiler -xml -detailLevel mini SPSoftwareDataType | grep Mac | cut -d ' ' -f 4 | cut -d . -f 2`
    #OS=${OS1}${OSnum}
    OS=mac${macos1}${macos2}
else
    flvr=`ups flavor`
    plat=`uname -p`
    OSnum=`lsb_release -r | cut -f2 | cut -f1 -d"."`
    OS=${OS1}${OSnum}
    if [ `lsb_release -d | cut  -f3 -d" "` = "SLF" ]
    then
       OS=slf${OSnum}
    fi
    if [ `lsb_release -i | cut -f2` = "ScientificFermi" ]
    then
       OS=slf${OSnum}
    fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "SLC" ]
    then
       OS=slc${OSnum}
    fi
    if [ `lsb_release -d | cut  -f4 -d" "` = "LTS" ]
    then
       OS=slf${OSnum}
    fi
fi

xqual=`echo ${artqual} | sed -e s%:%-%g`
fqual=`echo ${artqual} | sed -e s%:%_%g`
dqual=`echo ${artqual} | sed -e s%:%.%g`

set -x

cd ${PRODUCTS}

tar cjf artdaq-${dotversion}-${OS}-${plat}-${xqual}-${extraqual}.tar.bz2 \
   artdaq/${pkgver}.version/${flvr}_${fqual}_${extraqual} \
   artdaq/${pkgver}/ups \
   artdaq/${pkgver}/include  \
   ${fcldir} \
   artdaq/${pkgver}/source \
   artdaq/${pkgver}/${OS}.${plat}.${dqual}.${extraqual}
   
exit 0

